@@ -51,6 +51,7 @@ from secops.chronicle.data_table import (
     DataTableColumnType,
     replace_data_table_rows,
     update_data_table,
+    update_data_table_rows,
 )
 from secops.chronicle.entity import summarize_entity
 from secops.chronicle.gemini import (
@@ -66,12 +67,12 @@ from secops.chronicle.log_ingest import (
     extract_forwarder_id,
     get_forwarder,
     get_or_create_forwarder,
+    import_entities,
     ingest_log,
     list_forwarders,
     update_forwarder,
 )
 from secops.chronicle.log_types import (
-    LogType,
     get_all_log_types,
     get_log_type_description,
     is_valid_log_type,
@@ -132,7 +133,20 @@ from secops.chronicle.rule_exclusion import (
     update_rule_exclusion_deployment,
 )
 from secops.chronicle.rule_retrohunt import create_retrohunt, get_retrohunt
-from secops.chronicle.rule_set import batch_update_curated_rule_set_deployments
+from secops.chronicle.rule_set import (
+    batch_update_curated_rule_set_deployments,
+    list_curated_rule_sets,
+    list_curated_rule_set_categories,
+    list_curated_rules,
+    get_curated_rule,
+    get_curated_rule_set_category,
+    get_curated_rule_set,
+    list_curated_rule_set_deployments,
+    get_curated_rule_set_deployment,
+    get_curated_rule_set_deployment_by_name,
+    get_curated_rule_by_name,
+    update_curated_rule_set_deployment,
+)
 from secops.chronicle.rule_validation import ValidationResult
 from secops.chronicle.search import search_udm
 from secops.chronicle.stats import get_stats
@@ -142,10 +156,8 @@ from secops.chronicle.udm_mapping import (
 )
 from secops.chronicle.udm_search import (
     fetch_udm_search_csv,
-    find_udm_field_values,
-)
-from secops.chronicle.udm_search import (
     fetch_udm_search_view,
+    find_udm_field_values,
 )
 from secops.chronicle.validate import validate_query
 
@@ -164,6 +176,7 @@ __all__ = [
     # Natural Language Search
     "translate_nl_to_udm",
     # Entity
+    "import_entities",
     "summarize_entity",
     # IoC
     "list_iocs",
@@ -181,7 +194,6 @@ __all__ = [
     "extract_forwarder_id",
     "update_forwarder",
     # Log Types
-    "LogType",
     "get_all_log_types",
     "is_valid_log_type",
     "get_log_type_description",
@@ -228,6 +240,17 @@ __all__ = [
     "get_retrohunt",
     # Rule set operations
     "batch_update_curated_rule_set_deployments",
+    "list_curated_rule_sets",
+    "list_curated_rule_set_categories",
+    "list_curated_rules",
+    "get_curated_rule",
+    "get_curated_rule_set_category",
+    "get_curated_rule_set",
+    "list_curated_rule_set_deployments",
+    "get_curated_rule_set_deployment",
+    "get_curated_rule_set_deployment_by_name",
+    "get_curated_rule_by_name",
+    "update_curated_rule_set_deployment",
     # Native Dashboard
     "add_chart",
     "create_dashboard",
@@ -273,5 +296,6 @@ __all__ = [
     "ReferenceListSyntaxType",
     "ReferenceListView",
     "update_data_table",
+    "update_data_table_rows",
     "replace_data_table_rows",
 ]
