@@ -820,7 +820,7 @@ def ingest_log(
         APIError: If the API request fails
     """
     # Validate log type
-    if not is_valid_log_type(log_type) and not force_log_type:
+    if not is_valid_log_type(client, log_type) and not force_log_type:
         raise ValueError(
             f"Invalid log type: {log_type}. "
             "Use force_log_type=True to override."
@@ -1043,3 +1043,59 @@ def ingest_udm(
             response_data = {"raw_response": response.text}
 
     return response_data
+
+
+def import_entities(
+    client: "ChronicleClient",
+    entities: Union[Dict[str, Any], List[Dict[str, Any]]],
+    log_type: str,
+) -> Dict[str, Any]:
+    """Import entities into Chronicle.
+
+    Args:
+        client: ChronicleClient instance
+        entities: An entity dictionary or a list of entity dictionaries
+        log_type: The log type of the log from which this entity is created
+
+    Returns:
+        Dictionary containing the operation details for the ingestion
+
+    Raises:
+        ValueError: If any required fields are missing or entities malformed
+        APIError: If the API request fails
+    """
+    # Ensure we have a list of entities
+    if isinstance(entities, dict):
+        entities = [entities]
+
+    if not entities:
+        raise ValueError("No entities provided")
+
+    if not log_type:
+        raise ValueError("No log type provided")
+
+    # Prepare the request
+    url = f"{client.base_url}/{client.instance_id}/entities:import"
+
+    # Format the request body
+    body = {"inline_source": {"entities": entities, "log_type": log_type}}
+
+    # Make the API request
+    response = client.session.post(url, json=body)
+
+    # Check for errors
+    if response.status_code >= 400:
+        error_message = f"Failed to import entities: {response.text}"
+        raise APIError(error_message)
+
+    response_data = {}
+
+    # Parse response if it has content
+    if response.text.strip():
+        try:
+            response_data = response.json()
+        except ValueError:
+            # If JSON parsing fails, provide the raw text in the return value
+            response_data = {"raw_response": response.text}
+
+    return response_data
