@@ -27,6 +27,7 @@ from secops.chronicle.reference_list import ReferenceListSyntaxType, ReferenceLi
 import json
 import re
 import time
+import uuid
 
 
 @pytest.mark.integration
@@ -1603,6 +1604,136 @@ def test_update_data_table():
             print(f"Warning: Failed to clean up data table {dt_name}: {cleanup_error}")
 
 
+@pytest.mark.integration
+def test_update_data_table_rows():
+    """Test update_data_table_rows functionality with real API.
+    
+    This test creates a data table with initial rows, updates specific rows
+    using their full resource names, verifies the updates, and then cleans
+    up by deleting the data table.
+    """
+    client = SecOpsClient(service_account_info=SERVICE_ACCOUNT_JSON)
+    chronicle = client.chronicle(**CHRONICLE_CONFIG)
+    
+    # Create a unique data table name for this test using timestamp
+    dt_name = f"update_rows_test_{int(time.time())}"
+    
+    try:
+        print(f"\n>>> Testing update_data_table_rows for: {dt_name}")
+        
+        # Create a data table with initial rows
+        created_dt = chronicle.create_data_table(
+            name=dt_name,
+            description="Test Data Table for Update Rows",
+            header={
+                "hostname": DataTableColumnType.STRING,
+                "ip_address": DataTableColumnType.STRING,
+                "status": DataTableColumnType.STRING,
+            },
+            rows=[
+                ["server1.example.com", "10.0.0.1", "active"],
+                ["server2.example.com", "10.0.0.2", "active"],
+                ["server3.example.com", "10.0.0.3", "inactive"],
+            ],
+        )
+        
+        print(f"Created data table: {dt_name} with 3 initial rows")
+        assert created_dt.get("name").endswith(dt_name)
+        
+        # List rows to get their full resource names
+        initial_rows = chronicle.list_data_table_rows(dt_name)
+        assert len(initial_rows) == 3, (
+            f"Expected 3 initial rows, got {len(initial_rows)}"
+        )
+        
+        print(f"Retrieved {len(initial_rows)} rows with resource names")
+        
+        for row in initial_rows:
+            if "server1" in row["values"][0]:
+                row_1_name = row["name"]
+            elif "server2" in row["values"][0]:
+                row_2_name = row["name"]
+
+        # Prepare updates for the first two rows
+        row_updates = [
+            {
+                "name": row_1_name,
+                "values": [
+                    "server1-updated.example.com",
+                    "192.168.1.1",
+                    "maintenance",
+                ],
+            },
+            {
+                "name": row_2_name,
+                "values": [
+                    "server2-updated.example.com",
+                    "192.168.1.2",
+                    "maintenance",
+                ],
+            },
+        ]
+        
+        print(f"Updating 2 rows in data table: {dt_name}")
+        # Update the rows
+        update_results = chronicle.update_data_table_rows(
+            name=dt_name, row_updates=row_updates
+        )
+        
+        # Verify update response
+        assert len(update_results) == 1, (
+            "Expected single response for batch update"
+        )
+        assert "dataTableRows" in update_results[0], (
+            "Response should contain dataTableRows"
+        )
+        
+        print("Updates successful, verifying changes...")
+        
+        # Verify rows after update
+        updated_rows = chronicle.list_data_table_rows(dt_name)
+        assert len(updated_rows) == 3, (
+            f"Expected 3 rows after update, got {len(updated_rows)}"
+        )
+        
+        # Find the updated rows by their new values
+        updated_hostnames = set(
+            row["values"][0]
+            for row in updated_rows
+            if "updated" in row["values"][0]
+        )
+        assert len(updated_hostnames) == 2, (
+            f"Expected 2 updated hostnames, got {len(updated_hostnames)}"
+        )
+        assert "server1-updated.example.com" in updated_hostnames
+        assert "server2-updated.example.com" in updated_hostnames
+        
+        # Verify the third row remains unchanged
+        unchanged_row = [
+            row for row in updated_rows if "server3" in row["values"][0]
+        ]
+        assert len(unchanged_row) == 1
+        assert unchanged_row[0]["values"][2] == "inactive"
+        
+        print("All update_data_table_rows tests passed successfully")
+        
+    except Exception as e:
+        print(f"Error in test_update_data_table_rows: {str(e)}")
+        pytest.fail(f"Update data table rows test failed: {e}")
+        
+    finally:
+        # Clean up - delete the test data table
+        try:
+            print(f"Cleaning up - deleting data table: {dt_name}")
+            chronicle.delete_data_table(dt_name, force=True)
+            print("Data table deleted successfully")
+        except Exception as cleanup_error:
+            print(
+                f"Warning: Failed to clean up data table {dt_name}: "
+                f"{cleanup_error}"
+            )
+
+
 @pytest.mark.integration
 def test_chronicle_reference_lists():
     """Test Chronicle reference list functionality with real API."""
@@ -1828,3 +1959,253 @@ def test_find_udm_field_values():
     except Exception as e:
         print(f"Unexpected error in find_udm_field_values test: {str(e)}")
         raise
+
+
+@pytest.mark.integration
+def test_import_entities():
+    """Test entity import method of chronicle."""
+    # Create a SecOps client instance
+    client = SecOpsClient(service_account_info=SERVICE_ACCOUNT_JSON)
+    chronicle = client.chronicle(**CHRONICLE_CONFIG)
+
+    # Get current time for entity metadata
+    current_time = datetime.now(timezone.utc).isoformat().replace("+00:00", "Z")
+
+    # Create a test entity with a unique identifier
+    entity_id = f"test_user_{uuid.uuid4().hex[:8]}"
+    test_entity = {
+        "metadata": {
+            "collected_timestamp": current_time,
+            "entity_type": "USER",
+            "vendor_name": "SecOps SDK Test",
+            "product_name": "Entity Integration Test",
+        },
+        "entity": {
+            "user": {
+                "userid": entity_id,
+                "product_object_id": f"test_object_{uuid.uuid4().hex[:8]}",
+            }
+        },
+    }
+
+    try:
+        # Import the entity
+        print(f"\nImporting test entity with ID: {entity_id}")
+        result = chronicle.import_entities(
+            entities=test_entity, log_type="OKTA"
+        )
+
+        # Verify response
+        assert result is not None
+        assert result == {}
+        # An empty dict response indicates success
+        print(f"Import response: {result}")
+
+        # Test with multiple entities
+        entity_id2 = f"test_user_{uuid.uuid4().hex[:8]}"
+        test_entity2 = {
+            "metadata": {
+                "collected_timestamp": current_time,
+                "entity_type": "USER",
+                "vendor_name": "SecOps SDK Test",
+                "product_name": "Entity Integration Test",
+            },
+            "entity": {
+                "user": {
+                    "userid": entity_id2,
+                    "product_object_id": f"test_object_{uuid.uuid4().hex[:8]}",
+                }
+            },
+        }
+
+        # Import multiple entities
+        print(
+            f"\nImporting multiple test entities: {entity_id} and {entity_id2}"
+        )
+        multi_result = chronicle.import_entities(
+            entities=[test_entity, test_entity2], log_type="OKTA"
+        )
+
+        # Verify multiple entity response
+        assert multi_result is not None
+        assert multi_result == {}
+        print(f"Multiple entity import response: {multi_result}")
+
+    except APIError as e:
+        print(f"\nAPI Error details: {str(e)}")
+        # Skip the test rather than fail if permissions are not available
+        if "permission" in str(e).lower() or "not authorized" in str(e).lower():
+            pytest.skip("Insufficient permissions to import entities")
+        raise
+
+
+@pytest.mark.integration
+def test_chronicle_log_types_api_fetch():
+    """Test fetching log types from Chronicle API."""
+    if (
+        not CHRONICLE_CONFIG["customer_id"]
+        or not CHRONICLE_CONFIG["project_id"]
+    ):
+        pytest.skip("Chronicle configuration not available")
+
+    try:
+        client = SecOpsClient()
+        chronicle = client.chronicle(**CHRONICLE_CONFIG)
+
+        # Test fetching all log types (without pagination params)
+        all_log_types = chronicle.get_all_log_types()
+
+        # Verify response structure
+        assert isinstance(all_log_types, list)
+        assert len(all_log_types) > 0, "Should return at least some log types"
+
+        # Verify each item is a raw dict with API fields
+        for log_type_data in all_log_types[:5]:  # Check first 5
+            assert isinstance(log_type_data, dict)
+            assert "name" in log_type_data
+            assert "displayName" in log_type_data
+            # Extract ID from resource name
+            log_type_id = log_type_data["name"].split("/")[-1]
+            assert isinstance(log_type_id, str)
+            assert isinstance(log_type_data["displayName"], str)
+
+        print(f"\nFetched {len(all_log_types)} log types from API")
+
+        # Test with pagination
+        paginated_result = chronicle.get_all_log_types(page_size=10)
+        assert isinstance(paginated_result, list)
+        assert len(paginated_result) <= 10, (
+            "Should respect page_size limit"
+        )
+
+        print(f"Fetched {len(paginated_result)} log types with page_size=10")
+
+    except APIError as e:
+        print(f"\nAPI Error details: {str(e)}")
+        pytest.fail(f"API Error during log types fetch test: {e}")
+
+
+@pytest.mark.integration
+def test_chronicle_log_types_validation():
+    """Test log type validation using API data."""
+    if (
+        not CHRONICLE_CONFIG["customer_id"]
+        or not CHRONICLE_CONFIG["project_id"]
+    ):
+        pytest.skip("Chronicle configuration not available")
+
+    try:
+        client = SecOpsClient()
+        chronicle = client.chronicle(**CHRONICLE_CONFIG)
+
+        # Test validating common log types
+        common_log_types = ["OKTA", "AWS_CLOUDTRAIL", "WINDOWS"]
+
+        for log_type_id in common_log_types:
+            is_valid = chronicle.is_valid_log_type(log_type_id)
+            print(f"\n{log_type_id} is valid: {is_valid}")
+            # Note: Don't assert True because some instances
+            # may not have all log types
+            assert isinstance(is_valid, bool)
+
+        # Test with invalid log type
+        invalid_result = chronicle.is_valid_log_type("INVALID_LOG_TYPE_XYZ")
+        assert isinstance(invalid_result, bool)
+        print(f"\nINVALID_LOG_TYPE_XYZ is valid: {invalid_result}")
+
+    except APIError as e:
+        print(f"\nAPI Error details: {str(e)}")
+        pytest.fail(f"API Error during log type validation test: {e}")
+
+
+@pytest.mark.integration
+def test_chronicle_log_types_search():
+    """Test searching log types using API data."""
+    if (
+        not CHRONICLE_CONFIG["customer_id"]
+        or not CHRONICLE_CONFIG["project_id"]
+    ):
+        pytest.skip("Chronicle configuration not available")
+
+    try:
+        client = SecOpsClient()
+        chronicle = client.chronicle(**CHRONICLE_CONFIG)
+
+        # Test case-insensitive search
+        search_results = chronicle.search_log_types("okta")
+        assert isinstance(search_results, list)
+        print(f"\nFound {len(search_results)} results for 'okta'")
+
+        # Test search in description
+        description_results = chronicle.search_log_types(
+            "windows", search_in_description=True
+        )
+        assert isinstance(description_results, list)
+        print(f"Found {len(description_results)} results for 'windows'")
+
+        # Test case-sensitive search
+        case_sensitive_results = chronicle.search_log_types(
+            "OKTA", case_sensitive=True
+        )
+        assert isinstance(case_sensitive_results, list)
+        print(
+            f"Found {len(case_sensitive_results)} results for 'OKTA' "
+            f"(case-sensitive)"
+        )
+
+        # Test search without description
+        id_only_results = chronicle.search_log_types(
+            "AWS", search_in_description=False
+        )
+        assert isinstance(id_only_results, list)
+        print(
+            f"Found {len(id_only_results)} results for 'AWS' "
+            f"(ID only search)"
+        )
+
+    except APIError as e:
+        print(f"\nAPI Error details: {str(e)}")
+        pytest.fail(f"API Error during log types search test: {e}")
+
+
+@pytest.mark.integration
+def test_chronicle_log_types_description():
+    """Test getting log type descriptions using API data."""
+    if (
+        not CHRONICLE_CONFIG["customer_id"]
+        or not CHRONICLE_CONFIG["project_id"]
+    ):
+        pytest.skip("Chronicle configuration not available")
+
+    try:
+        client = SecOpsClient()
+        chronicle = client.chronicle(**CHRONICLE_CONFIG)
+
+        # Get all log types first
+        all_log_types = chronicle.get_all_log_types(page_size=5)
+
+        if len(all_log_types) > 0:
+            # Test getting description for first log type
+            log_type_data = all_log_types[0]
+            log_type_id = log_type_data["name"].split("/")[-1]
+            description = chronicle.get_log_type_description(log_type_id)
+
+            assert description is not None
+            assert isinstance(description, str)
+            assert description == log_type_data["displayName"]
+
+            print(
+                f"\nLog type: {log_type_id}, "
+                f"Description: {description}"
+            )
+
+        # Test with non-existent log type
+        invalid_description = chronicle.get_log_type_description(
+            "INVALID_LOG_TYPE_XYZ"
+        )
+        assert invalid_description is None
+        print("\nINVALID_LOG_TYPE_XYZ description: None (as expected)")
+
+    except APIError as e:
+        print(f"\nAPI Error details: {str(e)}")
+        pytest.fail(f"API Error during log type description test: {e}")
