@@ -16,8 +16,10 @@
 
 These tests require valid credentials and API access.
 """
+import os
 import json
 import subprocess
+import tempfile
 import time
 import uuid
 
@@ -544,3 +546,191 @@ def test_cli_dashboard_chart_lifecycle(cli_env, common_args):
 
             subprocess.run(delete_cmd, env=cli_env, check=False)
             print(f"Cleaned up dashboard with ID: {dashboard_id}")
+
+
+@pytest.mark.integration
+def test_cli_dashboard_export_import(cli_env, common_args):
+    """Test the dashboard export and import flow via CLI."""
+
+    # Generate unique IDs for test resources
+    unique_id = str(uuid.uuid4())[:8]
+    display_name = f"CLI Export Test Dashboard {unique_id}"
+    cleanup_ids = []
+    export_file_name = None
+
+    try:
+        # 1. Create a dashboard to export
+        create_cmd = (
+            ["secops"]
+            + common_args
+            + [
+                "dashboard",
+                "create",
+                "--display-name",
+                display_name,
+                "--description",
+                "CLI test dashboard for export-import",
+                "--access-type",
+                "PRIVATE",
+            ]
+        )
+
+        create_result = subprocess.run(
+            create_cmd, env=cli_env, capture_output=True, text=True
+        )
+
+        # Check that the command executed successfully
+        assert create_result.returncode == 0
+
+        # Load dashboard data and get ID
+        source_data = json.loads(create_result.stdout)
+        source_dashboard_id = source_data["name"].split("/")[-1]
+        print(f"Created dashboard with ID: {source_dashboard_id}")
+        cleanup_ids.append(source_dashboard_id)
+
+        # Wait for dashboard to be fully created
+        time.sleep(3)
+
+        # 2. Export the created dashboard
+        export_cmd = (
+            ["secops"]
+            + common_args
+            + [
+                "dashboard",
+                "export",
+                "--dashboard-names",
+                source_dashboard_id,
+            ]
+        )
+
+        export_result = subprocess.run(
+            export_cmd, env=cli_env, capture_output=True, text=True
+        )
+
+        # Check that the command executed successfully
+        assert export_result.returncode == 0
+
+        # Parse the export result
+        export_data = json.loads(export_result.stdout)
+        assert "inlineDestination" in export_data
+        assert "dashboards" in export_data["inlineDestination"]
+        assert len(export_data["inlineDestination"]["dashboards"]) > 0
+
+        # Save the export data to file
+        # Write import data to a temporary file
+        with tempfile.NamedTemporaryFile(
+            suffix=".json", mode="w+", delete=False
+        ) as temp_file:
+            temp_file.write(
+                json.dumps(
+                    export_data["inlineDestination"]["dashboards"][0][
+                        "dashboard"
+                    ]
+                )
+            )
+            export_file_name = temp_file.name
+
+        # 3. Import the dashboard from export file
+        import_cmd = (
+            ["secops"]
+            + common_args
+            + [
+                "dashboard",
+                "import",
+                "--dashboard-data-file",
+                export_file_name,
+            ]
+        )
+
+        import_result = subprocess.run(
+            import_cmd, env=cli_env, capture_output=True, text=True
+        )
+
+        # Check that the command executed successfully
+        assert import_result.returncode == 0
+
+        # Parse the import result
+        import_data = json.loads(import_result.stdout)
+        assert "results" in import_data
+        assert len(import_data["results"]) > 0
+        assert "dashboard" in import_data["results"][0]
+
+        # Extract the imported dashboard ID
+        imported_dashboard_id = import_data["results"][0]["dashboard"].split(
+            "/"
+        )[-1]
+        print(f"Imported dashboard with ID: {imported_dashboard_id}")
+        cleanup_ids.append(imported_dashboard_id)
+
+        # 4. Verify the imported dashboard matches the original
+        # Get the source dashboard
+        get_source_cmd = (
+            ["secops"]
+            + common_args
+            + [
+                "dashboard",
+                "get",
+                "--dashboard-id",
+                source_dashboard_id,
+            ]
+        )
+
+        source_result = subprocess.run(
+            get_source_cmd, env=cli_env, capture_output=True, text=True
+        )
+
+        # Get the imported dashboard
+        get_imported_cmd = (
+            ["secops"]
+            + common_args
+            + [
+                "dashboard",
+                "get",
+                "--dashboard-id",
+                imported_dashboard_id,
+            ]
+        )
+
+        imported_result = subprocess.run(
+            get_imported_cmd, env=cli_env, capture_output=True, text=True
+        )
+
+        # Check that both commands executed successfully
+        assert source_result.returncode == 0
+        assert imported_result.returncode == 0
+
+        # Parse the dashboard details
+        source_details = json.loads(source_result.stdout)
+        imported_details = json.loads(imported_result.stdout)
+
+        # Verify key properties match
+        assert imported_details["displayName"] == source_details["displayName"]
+        assert imported_details["description"] == source_details["description"]
+        assert imported_details["type"] == source_details["type"]
+        assert imported_details["access"] == source_details["access"]
+
+    finally:
+        # Clean up resources
+        # Delete dashboards
+        for dashboard_id in cleanup_ids:
+            if dashboard_id:
+                delete_cmd = (
+                    ["secops"]
+                    + common_args
+                    + [
+                        "dashboard",
+                        "delete",
+                        "--dashboard-id",
+                        dashboard_id,
+                    ]
+                )
+                subprocess.run(delete_cmd, env=cli_env, check=False)
+                print(f"Cleaned up dashboard with ID: {dashboard_id}")
+
+        # Clean up temporary files
+        try:
+            if export_file_name and os.path.exists(export_file_name):
+                os.remove(export_file_name)
+                print(f"Removed temporary file: {export_file_name}")
+        except Exception as e:
+            print(f"Error removing temporary file: {str(e)}")
